--------------------------------------------------------------------------------------------
-- Broker_TSMProfile - Displays the current TSM profile and lets you switch between profiles
--------------------------------------------------------------------------------------------
-- Broker_TSMProfile.lua
--
--[[

Did You ever post a lot of items to the auction house using a wrong TSM profile?

Broker_TSMProfile displays the current TSM profile and lets you change to a 
different profile with a simple click, so you never post items with the wrong profile again.

This addon requires TSM and a LDB addon (Bazooka etc.).

Author: Caraxe
All Rights Reserved

Version 0.1.2
------------------------------------------------------------------------------------]]

-----------------------------------------------------------------------------
-- Initializing Addon

local addonName, addon = ...
addon = LibStub("AceAddon-3.0"):NewAddon(addon, addonName, "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local addonVersionString = "V" .. GetAddOnMetadata(addonName, "Version")
local LibQTip = LibStub("LibQTip-1.0")

-----------------------------------------------------------------------------
-- Encounter TSM object reference hiding

local AceAddon = LibStub("AceAddon-3.0")
local TSMAddonName = ""
local TSMAddonObject = nil

function NewAddonH(objectorname, ...)
	local o = NewAddonO(objectorname, ...)
	if o then
		if o.name == "TradeSkillMaster" then
			TSMAddonName = o.name
			TSMAddonObject = o
			-- found it, back to normal
			AceAddon.NewAddon = NewAddonO
		end
	end
	return o
end

if AceAddon then
	NewAddonO = AceAddon.NewAddon
	AceAddon.NewAddon = NewAddonH
end

-----------------------------------------------------------------------------
-- Broker_TSMProfile

local function SecTimer()
	local profile = ""
	if TSMAddonObject then
		profile = TSMAddonObject.db:GetCurrentProfile()
	end
	addon.LDB.text = L["TSM Profile"] .. ": " .. profile
end

function addon:OnInitialize()
	addon.ExternalsInfo = ""

	local TSMV = GetAddOnMetadata("TradeSkillMaster", "Version")
	if (TSMV) then
		addon.ExternalsInfo = addon.ExternalsInfo .. "Trade Skill Master " .. TSMV
	end
end

function addon:OnEnable()
	if TSMAddonObject then
		-- for detecting externals switches
		addon.sectimer = C_Timer.NewTicker(1, SecTimer)

		local profile = TSMAddonObject.db:GetCurrentProfile()
		addon:Printf(addonVersionString .. ", " .. addon.ExternalsInfo .. L[" detected"] .. ", " .. L["TSM Profile"] .. ": " .. profile)

		-- leave it hidden
		-- AceAddon.addons[TSMAddonName] = TSMAddonObject
	else
		addon:Printf(addonVersionString .. ", " .. L["no TSM object found"] .. ".")
	end
end

local function tooltip_line_OnMouseUp(frame, profile, button)
	if TSMAddonObject then
		TSMAddonObject:ChangeProfile(profile)
		addon.LDB.text = L["TSM Profile"] .. ": " .. profile
	end
	addon:UpdateTooltip()
end

function addon:UpdateTooltip()
	if not LibQTip:IsAcquired(addon) then
		return
	end
	local tooltip = LibQTip:Acquire(addon)
	tooltip:Clear()
	tooltip:SetColumnLayout(2,"LEFT", "RIGHT")

	local line = tooltip:AddHeader()
	tooltip:SetCell(line, 1, "|cfffed100Broker_|cffffffffTSMProfile", nil, "CENTER", 2)
	line = tooltip:AddLine()
	tooltip:SetCell(line, 1, L["Profile"])
	tooltip:SetCell(line, 2, L["Status"])
	line = tooltip:AddSeparator()

	if TSMAddonObject then
		for i, profile in ipairs(TSMAddonObject.db:GetProfiles()) do
			line = tooltip:AddLine()
			tooltip:SetCell(line, 1, format("%d. %s", i, profile))
			if (TSMAddonObject.db:GetCurrentProfile() == profile) then
				tooltip:SetCell(line, 2, L["On"])
			else
				tooltip:SetCell(line, 2, "--")
			end
			tooltip:SetLineScript(line, "OnMouseUp", tooltip_line_OnMouseUp, profile)
		end
	end

	line = tooltip:AddSeparator()
	line = tooltip:AddLine()
	tooltip:SetCell(line, 1, "|cfffed100" .. L["Click to switch to profile"], nil, nil, 2)
	line = tooltip:AddLine()
	tooltip:SetCell(line, 1, "", nil, nil, 2)

	tooltip:UpdateScrolling()
end

-----------------------------------------------------------------------------
-- LDB Integration

local function do_OnEnter(frame)
	local tooltip = LibQTip:Acquire(addon)
	tooltip:SmartAnchorTo(frame)
	tooltip:SetAutoHideDelay(0.1, frame)
	tooltip:EnableMouse(true)
	addon:UpdateTooltip()
	tooltip:Show()
end

local function do_OnLeave()
	-- empty dummy
end

local function do_OnClick(frame, button)
	addon:UpdateTooltip()
end

addon.LDB = LibStub("LibDataBroker-1.1"):NewDataObject(addonName, {
	type = "data source", -- data source
	label = addonName,
	text = L["TSM Profile"] .. ": --",
	icon = "Interface\\Icons\\Trade_Engineering",
	OnEnter = do_OnEnter,
	OnLeave = do_OnLeave,
	OnClick = do_OnClick,
});

addon.LDB.OnTooltipShow = function(tt)
	tt:AddLine(addonName .. " " .. addonVersionString)
end

-- EOF
